# metronetpy

Python Package for programmatically controlling Security and Intrusion systems made by IESS (http://iessonline.com). Metronet is the cloud application provided by IESS that allows authenticated user to manage their own IESS security system. This was originally designed for [metronet](https://github.com/tulindo/metronet/) a custom_component for [Home Assistant](https://www.home-assistant.io/).

**NOTE:** Metronet has no official API; therefore, this library may stop
working at any time without warning.

# Credits
Originally inspired by [concord232](https://github.com/JasonCarter80/concord232) and [pythonegardia](https://github.com/jeroenterheerdt/python-egardia)
Additional scaffolding from [alexapy](https://gitlab.com/keatontaylor/alexapy)

# License
[GPLv30](LICENSE). By providing a contribution, you agree the contribution is licensed under GPLv3.
